@@ -111,7 +111,7 @@ class Task(APIResource):
                test_size: float = None, validation_size: float = None, fold_size: int = None, n_folds: int = None,
                horizon: int = None, validation_strategy: ValidationStrategy = None, cv_strategy: CVStrategy = None,
                forecast_horizon: int = None, model_life_time: int = None, refit_on_all: bool = None, wait: bool = False,
-               skip_if_exists: bool = False, api_key: str = None) -> WhatifyResponse:
+               skip_if_exists: bool = False, leaky_features: List[str] = None, api_key: str = None) -> WhatifyResponse:
         """
         Create and run a training task.
 
@@ -149,6 +149,7 @@ class Task(APIResource):
             model_life_time (Optional[int]): Something related to time-series models.
             refit_on_all (Optional[bool]): Determines if the final ensemble will be refit on all data after
                 search process is done.
+            leaky_features: add leaky features
             wait (Optional[bool]): Should the call be synchronous or not.
             skip_if_exists (Optional[bool]): Check if a Datasource with same name exists and skip if true.
             api_key (Optional[str]): Explicit api_key, not required if `fireflyai.authenticate` was run prior.
@@ -201,6 +202,7 @@ class Task(APIResource):
             'fold_size': fold_size,
             'validation_strategy': validation_strategy.value if validation_strategy is not None else None,
             'notes': notes,
+            'leaky_features': leaky_features,
             'refit_on_all': refit_on_all
         }
         task_config.update({k: v for k, v in user_config.items() if v is not None})
