@@ -140,8 +140,8 @@ class MyWhatify:
         :param only_total:
         :return:
         '''
-        return cls.magento_api(api_method='GET', table=table, page=page, limit=limit, add_total=add_total,
-                               only_total=only_total)
+        return cls.magento_api(api_method='GET', table=table, page=page, limit=limit, addtotal=add_total,
+                               onlytotal=only_total)
 
     @classmethod
     def post_magento(cls, body: str = None, table: str = None, page: str = None, limit: str = None,
@@ -156,14 +156,14 @@ class MyWhatify:
         :param only_total:
         :return:
         '''
-        return cls.magento_api(api_method='POST', body=body, table=table, page=page, limit=limit, add_total=add_total,
-                               only_total=only_total)
+        return cls.magento_api(api_method='POST', body=body, table=table, page=page, limit=limit, addtotal=add_total,
+                               onlytotal=only_total)
 
     @classmethod
     def magento_api(cls, api_method: str = None, body: str = None, table: str = None, page: str = None,
-                    limit: str = None, add_total: str = None, only_total: str = None):
+                    limit: str = None, addtotal: str = None, onlytotal: str = None):
         base_url = cls.magento_magento2url + '?'
-        base_vars = ['table', 'page', 'limit', 'add_total', 'only_total']
+        base_vars = ['table', 'page', 'limit', 'addtotal', 'onlytotal']
         for var in base_vars:
             if locals().get(var) is not None:
                 base_url += str(var) + '=' + str(locals().get(var)) + '&'
